tlslite.utils.codec.Parser

Package tlslite :: Package utils :: Module codec :: Class Parser |
[hide private]
[frames] | no frames]

# Class Parser

source code

Instance Methods | [hide private]
__init__(self, bytes) | source code
atLengthCheck(self) | source code
get(self, length) | source code
getFixBytes(self, lengthBytes) | source code
getFixList(self, length, lengthList) | source code
getVarBytes(self, lengthLength) | source code
getVarList(self, length, lengthLength) | source code
setLengthCheck(self, length) | source code
startLengthCheck(self, lengthLength) | source code
stopLengthCheck(self) | source code